@@ -174,7 +174,7 @@ ENV PATH=/opt/python/bin:$PATH
 RUN pip install --no-cache-dir -U pip
 RUN pip install --no-cache-dir setuptools wheel
 {}
-RUN pip install --no-cache-dir {} {}
+RUN pip install --no-cache-dir --timeout 120 {} {}
 ENV LD_LIBRARY_PATH=/opt/python/lib/python3.8/site-packages/nvidia/cuda_runtime/lib:/opt/python/lib/python3.8/site-packages/nvidia/cublas/lib:$LD_LIBRARY_PATH
 ENV LD_LIBRARY_PATH=/opt/python/lib/python3.8/site-packages/nvidia/cudnn/lib:/opt/python/lib/python3.8/site-packages/nvidia/curand/lib:$LD_LIBRARY_PATH
 ENV LD_LIBRARY_PATH=/opt/python/lib/python3.8/site-packages/nvidia/nvtx/lib:/opt/python/lib/python3.8/site-packages/nvidia/cufft/lib:$LD_LIBRARY_PATH
